@@ -1475,6 +1475,7 @@ def rel_spiral_square(detectors, x_motor, y_motor, x_range, y_range,
 def ramp_plan(go_plan,
               monitor_sig,
               inner_plan_func,
+              take_pre_data=True,
               timeout=None,
               period=None, md=None):
     '''Take data while ramping one or more positioners.
@@ -1510,6 +1511,9 @@ def ramp_plan(go_plan,
 
         In seconds
 
+    pre_data_enable: Bool, optional
+        If True, add a pre data at beginning
+
     period : float, optional
         If not None, take data no faster than this.  If None, take
         data as fast as possible
@@ -1531,7 +1535,8 @@ def ramp_plan(go_plan,
             fail_time = time.time() + timeout
 
         # take a 'pre' data point
-        yield from inner_plan_func()
+        if take_pre_data == True:
+            yield from inner_plan_func()
         # start the ramp
         status = (yield from go_plan)
 
